<?php
/**
 * Hitoma get options function
 *
 * @package Hitoma
 */

//======================================================================
//
// 取得
//
//======================================================================
/**
 * theme_mod_idから画像を取得
 * 取得出来ない場合はfalseを返す
 *
 * @param $mod_id      テーマオプション設定の名前
 * @param $default_url テーマオプション設定のデフォルト値
 *
 * @return bool|string
 */
if ( ! function_exists( 'hitoma_get_image_from_theme_mod_id' ) ):
	function hitoma_get_image_from_theme_mod_id( $mod_id, $default_url ) {
		$logo_url = esc_url( get_theme_mod( $mod_id, $default_url ) );

		// 画像が設定されていない
		if ( $logo_url === '' ) {
			return false;
		}

		// ユーザーの登録した画像
		$logo_id = attachment_url_to_postid( $logo_url );
		if ( $logo_id ) {
			$image_element = wp_get_attachment_image( $logo_id, 'full' );

			return $image_element;
		}

		/**
		 * デフォルト画像
		 * ローカルアドレスパスに変更してファイルの存在を確認
		 *
		 * なぜこんなことをしているのか？
		 * 1.customizerのデフォルト画像には絶対パスが必要
		 * 2.file_existsでファイルの存在を確認するためにはローカルの絶対パスが必要
		 */
		$local_logo_path = hitoma_change_url_to_local_path( $logo_url );
		if ( file_exists( $local_logo_path ) ) {
			$logo_size     = getimagesize( $local_logo_path );
			$logo_width    = $logo_size[0];
			$logo_height   = $logo_size[1];
			$image_element = '<img src="' . esc_url( $logo_url ) . '" width="' . esc_attr( $logo_width ) . '" height="' . esc_attr( $logo_height ) . '" alt="' . esc_attr( THEME_NAME ) . '">';

			return $image_element;
		}

		// ユーザーは画像登録しておらずデフォルト画像も存在していない
		return false;
	}
endif;

/**
 * theme_mod_idからテキストを取得
 * 取得出来ない場合はfalseを返す
 *
 * @param $mod_id       テーマオプション設定の名前
 * @param $default_text テーマオプション設定のデフォルト値
 *
 * @return bool|string
 */
if ( ! function_exists( 'hitoma_get_text_from_theme_mod_id' ) ):
	function hitoma_get_text_from_theme_mod_id( $mod_id, $default_text ) {
		$text = get_theme_mod( $mod_id, $default_text );

		if ( is_null( $text ) ) {
			return false;
		}

		return $text;
	}
endif;

/**
 * theme_mod_idから固定ページの内容を取得
 * 取得出来ない場合はfalseを返す
 *
 * ショートコードとフィルターとかに対応させるために面倒なことをしている
 *
 * @param $mod_id テーマオプション設定の名前
 *
 * @return bool|false|string
 */
if ( ! function_exists( 'hitoma_get_page_content_from_theme_mod_id' ) ):
	function hitoma_get_page_content_from_theme_mod_id( $mod_id ) {
		$page = hitoma_get_page_from_theme_mod_id( $mod_id );

		// ページが存在しない
		if ( ! $page ) {
			return false;
		}

		$page_query = new WP_Query( [
			'page_id'             => $page->ID,
			'posts_per_page'      => 1,
			'ignore_sticky_posts' => true,
			'no_found_rows'       => true,
		] );

		// ページが存在しない
		if ( ! $page_query->have_posts() ) {
			return false;
		}

		$content = '';

		while ( $page_query->have_posts() ) {
			$page_query->the_post();

			ob_start();

			the_content();

			$content = ob_get_clean();
		}

		// ページが存在しない
		if ( ! $content || $content === '' ) {
			return false;
		}

		wp_reset_postdata();

		return $content;
	}
endif;

/**
 * theme_mod_idから固定ページのタイトルを取得
 * 取得出来ない場合はfalseを返す
 *
 * @param $mod_id テーマオプション設定の名前
 *
 * @return bool|string
 */
if ( ! function_exists( 'hitoma_get_page_title_from_theme_mod_id' ) ):
	function hitoma_get_page_title_from_theme_mod_id( $mod_id ) {
		$page = hitoma_get_page_from_theme_mod_id( $mod_id );

		// ページが存在しない
		if ( ! $page ) {
			return false;
		}

		$content = get_the_title( $page );

		// コンテンツが存在しない
		if ( ! $content ) {
			return false;
		}

		return $content;
	}
endif;

/**
 * theme_mod_idから固定ページのURLを取得
 * 取得出来ない場合はfalseを返す
 *
 * @param $mod_id       テーマオプション設定の名前
 * @param $default_slug テーマオプション設定のデフォルト値
 *
 * @return bool|false|string
 */
if ( ! function_exists( 'hitoma_get_page_url_from_theme_mod_id' ) ):
	function hitoma_get_page_url_from_theme_mod_id( $mod_id, $default_slug ) {
		$slug = get_theme_mod( $mod_id, $default_slug );
		$page = get_page_by_path( $slug );

		// ページが存在しない
		// ここは他の関数と同じで ! $pageで良いのでは？
		if ( is_null( $page ) ) {
			return false;
		}

		$url = get_permalink( $page->ID );

		// URLが存在しない
		if ( ! $url ) {
			return false;
		}

		return $url;
	}
endif;

/**
 * theme_mod_idから固定ページを取得する
 * 取得出来ない場合はfalseを返す
 *
 * @param $mod_id テーマオプション設定の名前
 *
 * @return array|bool|WP_Post|null
 */
if ( ! function_exists( 'hitoma_get_page_from_theme_mod_id' ) ):
	function hitoma_get_page_from_theme_mod_id( $mod_id ) {
		$page_slug = get_theme_mod( $mod_id );

		// slugが入力されていない、あるいは空白である
		if ( ! $page_slug ) {
			return false;
		}

		$page_data = get_page_by_path( $page_slug );
		$page      = get_post( $page_data );

		// ページが存在しない
		if ( is_null( $page_data ) ) {
			return false;
		}

		return $page;
	}
endif;

/**
 * 固定ページが存在するかslugから確認
 * 取得出来た場合はtrueを返す
 * 取得出来ない場合はfalseを返す
 *
 * @param $mod_id テーマオプション設定の名前
 *
 * @return bool
 */
if ( ! function_exists( 'hitoma_is_page_exists_by_slug' ) ):
	function hitoma_is_page_exists_by_slug( $mod_id ) {
		$page = hitoma_get_page_from_theme_mod_id( $mod_id );

		// ページが存在しない
		if ( ! $page ) {
			return false;
		}

		return true;
	}
endif;

/**
 * URLをローカルパスに変更
 * 取得出来ない場合はfalseを返す
 *
 * file_exits関数ではローカルパスしか利用できないので用意した関数
 *
 * code from Cocoon WordPress Theme
 *
 * @param $url サイトのURL
 *
 * @return bool|mixed
 */
if ( ! function_exists( 'hitoma_change_url_to_local_path' ) ):
	function hitoma_change_url_to_local_path( $url ) {
		// $url      = https://server.dev/wp-content/themes/hitoma/assets/images/logo.png
		// $base_url = https://server.dev
		// ABSPATH   = /var/www/htdocs/public_html/
		$base_url = site_url();
		$includes_site_url = strpos( $url, $base_url );

		// $base_urlが一番最初でひっかかり 0(false) を返さなかったらここを通過する
		if ( $includes_site_url ) {
			return false;
		}

		// MEMO
		// DIRECTORY_SEPARATOR
		// https://code.i-harness.com/ja/q/69bee6
		$local_path = str_replace( $base_url, ABSPATH, $url );

		return $local_path;
	}
endif;